"""This module contains the general information for MgmtControllerFsmStage ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MgmtControllerFsmStageConsts:
    LAST_UPDATE_TIME_ = ""
    NAME_ACTIVATE_ADAPTOR_ACTIVATE = "ActivateAdaptorActivate"
    NAME_ACTIVATE_ADAPTOR_ACTIVATE_PEER = "ActivateAdaptorActivatePeer"
    NAME_ACTIVATE_ADAPTOR_BEGIN = "ActivateAdaptorBegin"
    NAME_ACTIVATE_ADAPTOR_FAIL = "ActivateAdaptorFail"
    NAME_ACTIVATE_ADAPTOR_POLL_ACTIVATE_STATUS = "ActivateAdaptorPollActivateStatus"
    NAME_ACTIVATE_ADAPTOR_POWER_OFF_SERVERS = "ActivateAdaptorPowerOffServers"
    NAME_ACTIVATE_ADAPTOR_POWER_ON_SERVERS = "ActivateAdaptorPowerOnServers"
    NAME_ACTIVATE_ADAPTOR_RESET = "ActivateAdaptorReset"
    NAME_ACTIVATE_ADAPTOR_SERVERS_POWER_OFF_COMPLETION = "ActivateAdaptorServersPowerOffCompletion"
    NAME_ACTIVATE_ADAPTOR_SUCCESS = "ActivateAdaptorSuccess"
    NAME_ACTIVATE_BMCACTIVATE = "ActivateBMCActivate"
    NAME_ACTIVATE_BMCBEGIN = "ActivateBMCBegin"
    NAME_ACTIVATE_BMCFAIL = "ActivateBMCFail"
    NAME_ACTIVATE_BMCRESET = "ActivateBMCReset"
    NAME_ACTIVATE_BMCSUCCESS = "ActivateBMCSuccess"
    NAME_ACTIVATE_CMCACTIVATE = "ActivateCMCActivate"
    NAME_ACTIVATE_CMCBEGIN = "ActivateCMCBegin"
    NAME_ACTIVATE_CMCFAIL = "ActivateCMCFail"
    NAME_ACTIVATE_CMCPOLL_ACTIVATION = "ActivateCMCPollActivation"
    NAME_ACTIVATE_CMCRESET = "ActivateCMCReset"
    NAME_ACTIVATE_CMCSUCCESS = "ActivateCMCSuccess"
    NAME_ACTIVATE_IOMACTIVATE = "ActivateIOMActivate"
    NAME_ACTIVATE_IOMBEGIN = "ActivateIOMBegin"
    NAME_ACTIVATE_IOMFAIL = "ActivateIOMFail"
    NAME_ACTIVATE_IOMRESET = "ActivateIOMReset"
    NAME_ACTIVATE_IOMSUCCESS = "ActivateIOMSuccess"
    NAME_ACTIVATE_LOCAL_DISK_ACTIVATE = "ActivateLocalDiskActivate"
    NAME_ACTIVATE_LOCAL_DISK_BEGIN = "ActivateLocalDiskBegin"
    NAME_ACTIVATE_LOCAL_DISK_FAIL = "ActivateLocalDiskFail"
    NAME_ACTIVATE_LOCAL_DISK_POLL_ACTIVATE_STATUS = "ActivateLocalDiskPollActivateStatus"
    NAME_ACTIVATE_LOCAL_DISK_SUCCESS = "ActivateLocalDiskSuccess"
    NAME_ACTIVATE_SAS_EXPANDER_ACTIVATE = "ActivateSasExpanderActivate"
    NAME_ACTIVATE_SAS_EXPANDER_BEGIN = "ActivateSasExpanderBegin"
    NAME_ACTIVATE_SAS_EXPANDER_FAIL = "ActivateSasExpanderFail"
    NAME_ACTIVATE_SAS_EXPANDER_POLL_ACTIVATE_STATUS = "ActivateSasExpanderPollActivateStatus"
    NAME_ACTIVATE_SAS_EXPANDER_SUCCESS = "ActivateSasExpanderSuccess"
    NAME_ACTIVATE_SAS_EXPANDER_WAIT_FOR_ACTIVATION = "ActivateSasExpanderWaitForActivation"
    NAME_ACTIVATE_STORAGE_SERVER_CMCACTIVATE = "ActivateStorageServerCMCActivate"
    NAME_ACTIVATE_STORAGE_SERVER_CMCBEGIN = "ActivateStorageServerCMCBegin"
    NAME_ACTIVATE_STORAGE_SERVER_CMCFAIL = "ActivateStorageServerCMCFail"
    NAME_ACTIVATE_STORAGE_SERVER_CMCPOLL_ACTIVATION = "ActivateStorageServerCMCPollActivation"
    NAME_ACTIVATE_STORAGE_SERVER_CMCRESET = "ActivateStorageServerCMCReset"
    NAME_ACTIVATE_STORAGE_SERVER_CMCSUCCESS = "ActivateStorageServerCMCSuccess"
    NAME_CONFIGURE_SW_PERSONALITIES_BEGIN = "ConfigureSwPersonalitiesBegin"
    NAME_CONFIGURE_SW_PERSONALITIES_EXECUTE = "ConfigureSwPersonalitiesExecute"
    NAME_CONFIGURE_SW_PERSONALITIES_FAIL = "ConfigureSwPersonalitiesFail"
    NAME_CONFIGURE_SW_PERSONALITIES_SUCCESS = "ConfigureSwPersonalitiesSuccess"
    NAME_ENABLE_SECURE_BOOT_BEGIN = "EnableSecureBootBegin"
    NAME_ENABLE_SECURE_BOOT_FAIL = "EnableSecureBootFail"
    NAME_ENABLE_SECURE_BOOT_POLL_SECURE_BOOT_STATUS = "EnableSecureBootPollSecureBootStatus"
    NAME_ENABLE_SECURE_BOOT_POLL_UPDATE_STATUS = "EnableSecureBootPollUpdateStatus"
    NAME_ENABLE_SECURE_BOOT_RESET = "EnableSecureBootReset"
    NAME_ENABLE_SECURE_BOOT_SUCCESS = "EnableSecureBootSuccess"
    NAME_ENABLE_SECURE_BOOT_UPDATE_REQUEST = "EnableSecureBootUpdateRequest"
    NAME_EXT_MGMT_IF_CONFIG_BEGIN = "ExtMgmtIfConfigBegin"
    NAME_EXT_MGMT_IF_CONFIG_FAIL = "ExtMgmtIfConfigFail"
    NAME_EXT_MGMT_IF_CONFIG_PRIMARY = "ExtMgmtIfConfigPrimary"
    NAME_EXT_MGMT_IF_CONFIG_SECONDARY = "ExtMgmtIfConfigSecondary"
    NAME_EXT_MGMT_IF_CONFIG_SUCCESS = "ExtMgmtIfConfigSuccess"
    NAME_EXT_MGMT_INTERFACE_CONFIG_ACTIVE = "ExtMgmtInterfaceConfigActive"
    NAME_EXT_MGMT_INTERFACE_CONFIG_BEGIN = "ExtMgmtInterfaceConfigBegin"
    NAME_EXT_MGMT_INTERFACE_CONFIG_CIMCVLAN_CFG_LOCAL = "ExtMgmtInterfaceConfigCIMCVlanCfgLocal"
    NAME_EXT_MGMT_INTERFACE_CONFIG_CIMCVLAN_CFG_PEER = "ExtMgmtInterfaceConfigCIMCVlanCfgPeer"
    NAME_EXT_MGMT_INTERFACE_CONFIG_CMCVLAN_CFG = "ExtMgmtInterfaceConfigCMCVlanCfg"
    NAME_EXT_MGMT_INTERFACE_CONFIG_CMCVLAN_CFG_PEER = "ExtMgmtInterfaceConfigCMCVlanCfgPeer"
    NAME_EXT_MGMT_INTERFACE_CONFIG_FAIL = "ExtMgmtInterfaceConfigFail"
    NAME_EXT_MGMT_INTERFACE_CONFIG_STANDBY_CMCVLAN_CFG = "ExtMgmtInterfaceConfigStandbyCMCVlanCfg"
    NAME_EXT_MGMT_INTERFACE_CONFIG_SUCCESS = "ExtMgmtInterfaceConfigSuccess"
    NAME_KVM_CERT_BEGIN = "KvmCertBegin"
    NAME_KVM_CERT_CONFIG = "KvmCertConfig"
    NAME_KVM_CERT_FAIL = "KvmCertFail"
    NAME_KVM_CERT_RESET_CIMC = "KvmCertResetCimc"
    NAME_KVM_CERT_SUCCESS = "KvmCertSuccess"
    NAME_LOCK_CONFIG_BEGIN = "LockConfigBegin"
    NAME_LOCK_CONFIG_FAIL = "LockConfigFail"
    NAME_LOCK_CONFIG_POWER_BUTTON_LOCK_CONFIG = "LockConfigPowerButtonLockConfig"
    NAME_LOCK_CONFIG_SUCCESS = "LockConfigSuccess"
    NAME_ONLINE_BEGIN = "OnlineBegin"
    NAME_ONLINE_BMC_CONFIGURE_CONN_LOCAL = "OnlineBmcConfigureConnLocal"
    NAME_ONLINE_BMC_CONFIGURE_CONN_PEER = "OnlineBmcConfigureConnPeer"
    NAME_ONLINE_FAIL = "OnlineFail"
    NAME_ONLINE_SUCCESS = "OnlineSuccess"
    NAME_ONLINE_SW_CONFIGURE_CONN_LOCAL = "OnlineSwConfigureConnLocal"
    NAME_ONLINE_SW_CONFIGURE_CONN_PEER = "OnlineSwConfigureConnPeer"
    NAME_POWER_BUDGET_RECLAIM_CONFIG_BEGIN = "PowerBudgetReclaimConfigBegin"
    NAME_POWER_BUDGET_RECLAIM_CONFIG_FAIL = "PowerBudgetReclaimConfigFail"
    NAME_POWER_BUDGET_RECLAIM_CONFIG_POWER_OFF_RECLAIM = "PowerBudgetReclaimConfigPowerOffReclaim"
    NAME_POWER_BUDGET_RECLAIM_CONFIG_POWER_OFF_WAIT = "PowerBudgetReclaimConfigPowerOffWait"
    NAME_POWER_BUDGET_RECLAIM_CONFIG_SUCCESS = "PowerBudgetReclaimConfigSuccess"
    NAME_POWER_CAP_BEGIN = "PowerCapBegin"
    NAME_POWER_CAP_CONFIG = "PowerCapConfig"
    NAME_POWER_CAP_FAIL = "PowerCapFail"
    NAME_POWER_CAP_SUCCESS = "PowerCapSuccess"
    NAME_REGISTRY_CONFIG_BEGIN = "RegistryConfigBegin"
    NAME_REGISTRY_CONFIG_FAIL = "RegistryConfigFail"
    NAME_REGISTRY_CONFIG_REMOVE = "RegistryConfigRemove"
    NAME_REGISTRY_CONFIG_REMOVE_PEER = "RegistryConfigRemovePeer"
    NAME_REGISTRY_CONFIG_SUCCESS = "RegistryConfigSuccess"
    NAME_SYS_CONFIG_BEGIN = "SysConfigBegin"
    NAME_SYS_CONFIG_FAIL = "SysConfigFail"
    NAME_SYS_CONFIG_PRIMARY = "SysConfigPrimary"
    NAME_SYS_CONFIG_SECONDARY = "SysConfigSecondary"
    NAME_SYS_CONFIG_SUCCESS = "SysConfigSuccess"
    NAME_UPDATE_ADAPTOR_BEGIN = "UpdateAdaptorBegin"
    NAME_UPDATE_ADAPTOR_FAIL = "UpdateAdaptorFail"
    NAME_UPDATE_ADAPTOR_POLL_UPDATE_STATUS = "UpdateAdaptorPollUpdateStatus"
    NAME_UPDATE_ADAPTOR_SUCCESS = "UpdateAdaptorSuccess"
    NAME_UPDATE_ADAPTOR_UPDATE_REQUEST = "UpdateAdaptorUpdateRequest"
    NAME_UPDATE_ADAPTOR_UPDATE_REQUEST_PEER = "UpdateAdaptorUpdateRequestPeer"
    NAME_UPDATE_BMCBEGIN = "UpdateBMCBegin"
    NAME_UPDATE_BMCFAIL = "UpdateBMCFail"
    NAME_UPDATE_BMCPOLL_UPDATE_STATUS = "UpdateBMCPollUpdateStatus"
    NAME_UPDATE_BMCSUCCESS = "UpdateBMCSuccess"
    NAME_UPDATE_BMCUPDATE_REQUEST = "UpdateBMCUpdateRequest"
    NAME_UPDATE_BOARD_CONTROLLER_BEGIN = "UpdateBoardControllerBegin"
    NAME_UPDATE_BOARD_CONTROLLER_FAIL = "UpdateBoardControllerFail"
    NAME_UPDATE_BOARD_CONTROLLER_POLL_UPDATE_STATUS = "UpdateBoardControllerPollUpdateStatus"
    NAME_UPDATE_BOARD_CONTROLLER_POWER_OFF_SERVERS = "UpdateBoardControllerPowerOffServers"
    NAME_UPDATE_BOARD_CONTROLLER_POWER_ON_SERVERS = "UpdateBoardControllerPowerOnServers"
    NAME_UPDATE_BOARD_CONTROLLER_PREPARE_FOR_UPDATE = "UpdateBoardControllerPrepareForUpdate"
    NAME_UPDATE_BOARD_CONTROLLER_SERVERS_POWER_OFF_COMPLETION = "UpdateBoardControllerServersPowerOffCompletion"
    NAME_UPDATE_BOARD_CONTROLLER_SUCCESS = "UpdateBoardControllerSuccess"
    NAME_UPDATE_BOARD_CONTROLLER_UPDATE_REQUEST = "UpdateBoardControllerUpdateRequest"
    NAME_UPDATE_CMCBEGIN = "UpdateCMCBegin"
    NAME_UPDATE_CMCFAIL = "UpdateCMCFail"
    NAME_UPDATE_CMCPOLL_UPDATE_STATUS = "UpdateCMCPollUpdateStatus"
    NAME_UPDATE_CMCSUCCESS = "UpdateCMCSuccess"
    NAME_UPDATE_CMCUPDATE_REQUEST = "UpdateCMCUpdateRequest"
    NAME_UPDATE_IOMBEGIN = "UpdateIOMBegin"
    NAME_UPDATE_IOMCOPY_IOMIMG_TO_SUB = "UpdateIOMCopyIOMImgToSub"
    NAME_UPDATE_IOMCOPY_IMG_FROM_REP = "UpdateIOMCopyImgFromRep"
    NAME_UPDATE_IOMFAIL = "UpdateIOMFail"
    NAME_UPDATE_IOMPOLL_UPDATE_STATUS = "UpdateIOMPollUpdateStatus"
    NAME_UPDATE_IOMSUCCESS = "UpdateIOMSuccess"
    NAME_UPDATE_IOMUPDATE_REQUEST = "UpdateIOMUpdateRequest"
    NAME_UPDATE_RAID_CONTROLLER_ACTIVATE = "UpdateRaidControllerActivate"
    NAME_UPDATE_RAID_CONTROLLER_BEGIN = "UpdateRaidControllerBegin"
    NAME_UPDATE_RAID_CONTROLLER_FAIL = "UpdateRaidControllerFail"
    NAME_UPDATE_RAID_CONTROLLER_POLL_ACTIVATION = "UpdateRaidControllerPollActivation"
    NAME_UPDATE_RAID_CONTROLLER_POLL_UPDATE_STATUS = "UpdateRaidControllerPollUpdateStatus"
    NAME_UPDATE_RAID_CONTROLLER_POWER_OFF_SERVERS = "UpdateRaidControllerPowerOffServers"
    NAME_UPDATE_RAID_CONTROLLER_POWER_ON_SERVERS = "UpdateRaidControllerPowerOnServers"
    NAME_UPDATE_RAID_CONTROLLER_SERVERS_POWER_OFF_COMPLETION = "UpdateRaidControllerServersPowerOffCompletion"
    NAME_UPDATE_RAID_CONTROLLER_SUCCESS = "UpdateRaidControllerSuccess"
    NAME_UPDATE_RAID_CONTROLLER_UPDATE_REQUEST = "UpdateRaidControllerUpdateRequest"
    NAME_UPDATE_SAS_EXPANDER_BEGIN = "UpdateSasExpanderBegin"
    NAME_UPDATE_SAS_EXPANDER_FAIL = "UpdateSasExpanderFail"
    NAME_UPDATE_SAS_EXPANDER_POLL_UPDATE_STATUS = "UpdateSasExpanderPollUpdateStatus"
    NAME_UPDATE_SAS_EXPANDER_SUCCESS = "UpdateSasExpanderSuccess"
    NAME_UPDATE_SAS_EXPANDER_UPDATE_REQUEST = "UpdateSasExpanderUpdateRequest"
    NAME_UPDATE_SECURE_FPGAACTIVATE_LOCAL = "UpdateSecureFPGAActivateLocal"
    NAME_UPDATE_SECURE_FPGAACTIVATE_REMOTE = "UpdateSecureFPGAActivateRemote"
    NAME_UPDATE_SECURE_FPGABEGIN = "UpdateSecureFPGABegin"
    NAME_UPDATE_SECURE_FPGAFAIL = "UpdateSecureFPGAFail"
    NAME_UPDATE_SECURE_FPGAPOLL_ACTIVATE = "UpdateSecureFPGAPollActivate"
    NAME_UPDATE_SECURE_FPGASUCCESS = "UpdateSecureFPGASuccess"
    NAME_UPDATE_STORAGE_SERVER_CMCBEGIN = "UpdateStorageServerCMCBegin"
    NAME_UPDATE_STORAGE_SERVER_CMCFAIL = "UpdateStorageServerCMCFail"
    NAME_UPDATE_STORAGE_SERVER_CMCPOLL_UPDATE_STATUS = "UpdateStorageServerCMCPollUpdateStatus"
    NAME_UPDATE_STORAGE_SERVER_CMCSUCCESS = "UpdateStorageServerCMCSuccess"
    NAME_UPDATE_STORAGE_SERVER_CMCUPDATE_REQUEST = "UpdateStorageServerCMCUpdateRequest"
    NAME_UPDATE_SWITCH_BEGIN = "UpdateSwitchBegin"
    NAME_UPDATE_SWITCH_FAIL = "UpdateSwitchFail"
    NAME_UPDATE_SWITCH_RESET_LOCAL = "UpdateSwitchResetLocal"
    NAME_UPDATE_SWITCH_RESET_REMOTE = "UpdateSwitchResetRemote"
    NAME_UPDATE_SWITCH_SUCCESS = "UpdateSwitchSuccess"
    NAME_UPDATE_SWITCH_UPDATE_LOCAL = "UpdateSwitchUpdateLocal"
    NAME_UPDATE_SWITCH_UPDATE_REMOTE = "UpdateSwitchUpdateRemote"
    NAME_UPDATE_SWITCH_UPDATE_SP_LOCAL = "UpdateSwitchUpdateSpLocal"
    NAME_UPDATE_SWITCH_UPDATE_SP_REMOTE = "UpdateSwitchUpdateSpRemote"
    NAME_UPDATE_SWITCH_VERIFY_LOCAL = "UpdateSwitchVerifyLocal"
    NAME_UPDATE_SWITCH_VERIFY_REMOTE = "UpdateSwitchVerifyRemote"
    NAME_UPDATE_UCSMANAGER_BEGIN = "UpdateUCSManagerBegin"
    NAME_UPDATE_UCSMANAGER_EXECUTE = "UpdateUCSManagerExecute"
    NAME_UPDATE_UCSMANAGER_FAIL = "UpdateUCSManagerFail"
    NAME_UPDATE_UCSMANAGER_SPBEGIN = "UpdateUCSManagerSPBegin"
    NAME_UPDATE_UCSMANAGER_SPEXECUTE = "UpdateUCSManagerSPExecute"
    NAME_UPDATE_UCSMANAGER_SPFAIL = "UpdateUCSManagerSPFail"
    NAME_UPDATE_UCSMANAGER_SPSTART = "UpdateUCSManagerSPStart"
    NAME_UPDATE_UCSMANAGER_SPSUCCESS = "UpdateUCSManagerSPSuccess"
    NAME_UPDATE_UCSMANAGER_START = "UpdateUCSManagerStart"
    NAME_UPDATE_UCSMANAGER_SUCCESS = "UpdateUCSManagerSuccess"
    NAME_UPGRADE_BOARD_CONTROLLER_BEGIN = "UpgradeBoardControllerBegin"
    NAME_UPGRADE_BOARD_CONTROLLER_FAIL = "UpgradeBoardControllerFail"
    NAME_UPGRADE_BOARD_CONTROLLER_POLL_UPDATE_STATUS = "UpgradeBoardControllerPollUpdateStatus"
    NAME_UPGRADE_BOARD_CONTROLLER_POWER_OFF_SERVERS = "UpgradeBoardControllerPowerOffServers"
    NAME_UPGRADE_BOARD_CONTROLLER_POWER_ON_SERVERS = "UpgradeBoardControllerPowerOnServers"
    NAME_UPGRADE_BOARD_CONTROLLER_PREPARE_FOR_UPDATE = "UpgradeBoardControllerPrepareForUpdate"
    NAME_UPGRADE_BOARD_CONTROLLER_SERVERS_POWER_OFF_COMPLETION = "UpgradeBoardControllerServersPowerOffCompletion"
    NAME_UPGRADE_BOARD_CONTROLLER_SUCCESS = "UpgradeBoardControllerSuccess"
    NAME_UPGRADE_BOARD_CONTROLLER_UPDATE_REQUEST = "UpgradeBoardControllerUpdateRequest"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class MgmtControllerFsmStage(ManagedObject):
    """This is MgmtControllerFsmStage class."""

    consts = MgmtControllerFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("MgmtControllerFsmStage", "mgmtControllerFsmStage", "stage-[name]", VersionMeta.Version211a, "OutputOnly", 0xf, [], [""], ['mgmtControllerFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version211a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []),
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version211a, MoPropertyMeta.NAMING, None, None, None, None, ["ActivateAdaptorActivate", "ActivateAdaptorActivatePeer", "ActivateAdaptorBegin", "ActivateAdaptorFail", "ActivateAdaptorPollActivateStatus", "ActivateAdaptorPowerOffServers", "ActivateAdaptorPowerOnServers", "ActivateAdaptorReset", "ActivateAdaptorServersPowerOffCompletion", "ActivateAdaptorSuccess", "ActivateBMCActivate", "ActivateBMCBegin", "ActivateBMCFail", "ActivateBMCReset", "ActivateBMCSuccess", "ActivateCMCActivate", "ActivateCMCBegin", "ActivateCMCFail", "ActivateCMCPollActivation", "ActivateCMCReset", "ActivateCMCSuccess", "ActivateIOMActivate", "ActivateIOMBegin", "ActivateIOMFail", "ActivateIOMReset", "ActivateIOMSuccess", "ActivateLocalDiskActivate", "ActivateLocalDiskBegin", "ActivateLocalDiskFail", "ActivateLocalDiskPollActivateStatus", "ActivateLocalDiskSuccess", "ActivateSasExpanderActivate", "ActivateSasExpanderBegin", "ActivateSasExpanderFail", "ActivateSasExpanderPollActivateStatus", "ActivateSasExpanderSuccess", "ActivateSasExpanderWaitForActivation", "ActivateStorageServerCMCActivate", "ActivateStorageServerCMCBegin", "ActivateStorageServerCMCFail", "ActivateStorageServerCMCPollActivation", "ActivateStorageServerCMCReset", "ActivateStorageServerCMCSuccess", "ConfigureSwPersonalitiesBegin", "ConfigureSwPersonalitiesExecute", "ConfigureSwPersonalitiesFail", "ConfigureSwPersonalitiesSuccess", "EnableSecureBootBegin", "EnableSecureBootFail", "EnableSecureBootPollSecureBootStatus", "EnableSecureBootPollUpdateStatus", "EnableSecureBootReset", "EnableSecureBootSuccess", "EnableSecureBootUpdateRequest", "ExtMgmtIfConfigBegin", "ExtMgmtIfConfigFail", "ExtMgmtIfConfigPrimary", "ExtMgmtIfConfigSecondary", "ExtMgmtIfConfigSuccess", "ExtMgmtInterfaceConfigActive", "ExtMgmtInterfaceConfigBegin", "ExtMgmtInterfaceConfigCIMCVlanCfgLocal", "ExtMgmtInterfaceConfigCIMCVlanCfgPeer", "ExtMgmtInterfaceConfigCMCVlanCfg", "ExtMgmtInterfaceConfigCMCVlanCfgPeer", "ExtMgmtInterfaceConfigFail", "ExtMgmtInterfaceConfigStandbyCMCVlanCfg", "ExtMgmtInterfaceConfigSuccess", "KvmCertBegin", "KvmCertConfig", "KvmCertFail", "KvmCertResetCimc", "KvmCertSuccess", "LockConfigBegin", "LockConfigFail", "LockConfigPowerButtonLockConfig", "LockConfigSuccess", "OnlineBegin", "OnlineBmcConfigureConnLocal", "OnlineBmcConfigureConnPeer", "OnlineFail", "OnlineSuccess", "OnlineSwConfigureConnLocal", "OnlineSwConfigureConnPeer", "PowerBudgetReclaimConfigBegin", "PowerBudgetReclaimConfigFail", "PowerBudgetReclaimConfigPowerOffReclaim", "PowerBudgetReclaimConfigPowerOffWait", "PowerBudgetReclaimConfigSuccess", "PowerCapBegin", "PowerCapConfig", "PowerCapFail", "PowerCapSuccess", "RegistryConfigBegin", "RegistryConfigFail", "RegistryConfigRemove", "RegistryConfigRemovePeer", "RegistryConfigSuccess", "SysConfigBegin", "SysConfigFail", "SysConfigPrimary", "SysConfigSecondary", "SysConfigSuccess", "UpdateAdaptorBegin", "UpdateAdaptorFail", "UpdateAdaptorPollUpdateStatus", "UpdateAdaptorSuccess", "UpdateAdaptorUpdateRequest", "UpdateAdaptorUpdateRequestPeer", "UpdateBMCBegin", "UpdateBMCFail", "UpdateBMCPollUpdateStatus", "UpdateBMCSuccess", "UpdateBMCUpdateRequest", "UpdateBoardControllerBegin", "UpdateBoardControllerFail", "UpdateBoardControllerPollUpdateStatus", "UpdateBoardControllerPowerOffServers", "UpdateBoardControllerPowerOnServers", "UpdateBoardControllerPrepareForUpdate", "UpdateBoardControllerServersPowerOffCompletion", "UpdateBoardControllerSuccess", "UpdateBoardControllerUpdateRequest", "UpdateCMCBegin", "UpdateCMCFail", "UpdateCMCPollUpdateStatus", "UpdateCMCSuccess", "UpdateCMCUpdateRequest", "UpdateIOMBegin", "UpdateIOMCopyIOMImgToSub", "UpdateIOMCopyImgFromRep", "UpdateIOMFail", "UpdateIOMPollUpdateStatus", "UpdateIOMSuccess", "UpdateIOMUpdateRequest", "UpdateRaidControllerActivate", "UpdateRaidControllerBegin", "UpdateRaidControllerFail", "UpdateRaidControllerPollActivation", "UpdateRaidControllerPollUpdateStatus", "UpdateRaidControllerPowerOffServers", "UpdateRaidControllerPowerOnServers", "UpdateRaidControllerServersPowerOffCompletion", "UpdateRaidControllerSuccess", "UpdateRaidControllerUpdateRequest", "UpdateSasExpanderBegin", "UpdateSasExpanderFail", "UpdateSasExpanderPollUpdateStatus", "UpdateSasExpanderSuccess", "UpdateSasExpanderUpdateRequest", "UpdateSecureFPGAActivateLocal", "UpdateSecureFPGAActivateRemote", "UpdateSecureFPGABegin", "UpdateSecureFPGAFail", "UpdateSecureFPGAPollActivate", "UpdateSecureFPGASuccess", "UpdateStorageServerCMCBegin", "UpdateStorageServerCMCFail", "UpdateStorageServerCMCPollUpdateStatus", "UpdateStorageServerCMCSuccess", "UpdateStorageServerCMCUpdateRequest", "UpdateSwitchBegin", "UpdateSwitchFail", "UpdateSwitchResetLocal", "UpdateSwitchResetRemote", "UpdateSwitchSuccess", "UpdateSwitchUpdateLocal", "UpdateSwitchUpdateRemote", "UpdateSwitchUpdateSpLocal", "UpdateSwitchUpdateSpRemote", "UpdateSwitchVerifyLocal", "UpdateSwitchVerifyRemote", "UpdateUCSManagerBegin", "UpdateUCSManagerExecute", "UpdateUCSManagerFail", "UpdateUCSManagerSPBegin", "UpdateUCSManagerSPExecute", "UpdateUCSManagerSPFail", "UpdateUCSManagerSPStart", "UpdateUCSManagerSPSuccess", "UpdateUCSManagerStart", "UpdateUCSManagerSuccess", "UpgradeBoardControllerBegin", "UpgradeBoardControllerFail", "UpgradeBoardControllerPollUpdateStatus", "UpgradeBoardControllerPowerOffServers", "UpgradeBoardControllerPowerOnServers", "UpgradeBoardControllerPrepareForUpdate", "UpgradeBoardControllerServersPowerOffCompletion", "UpgradeBoardControllerSuccess", "UpgradeBoardControllerUpdateRequest", "nop"], []),
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "sacl": "sacl", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.sacl = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "MgmtControllerFsmStage", parent_mo_or_dn, **kwargs)



"""This module contains the meta information of ApeDeleteSfish ExternalMethod."""

from ..ucscoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ApeDeleteSfish", "apeDeleteSfish", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_vm_switch_dn": MethodPropertyMeta("InVmSwitchDn", "inVmSwitchDn", "ReferenceObject", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inVmSwitchDn": "in_vm_switch_dn",
}



"""This module contains the general information for EquipmentLocalDiskControllerDef ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class EquipmentLocalDiskControllerDefConsts:
    AUTO_CONFIG_MODE_SUPPORTED_FALSE = "false"
    AUTO_CONFIG_MODE_SUPPORTED_NO = "no"
    AUTO_CONFIG_MODE_SUPPORTED_TRUE = "true"
    AUTO_CONFIG_MODE_SUPPORTED_YES = "yes"
    CONFIG_PARM_MOD_SUPPORTED_FALSE = "false"
    CONFIG_PARM_MOD_SUPPORTED_NO = "no"
    CONFIG_PARM_MOD_SUPPORTED_TRUE = "true"
    CONFIG_PARM_MOD_SUPPORTED_YES = "yes"
    CONTROLLER_DEF_TYPE_DUAL = "dual"
    CONTROLLER_DEF_TYPE_EMBEDDED = "embedded"
    CONTROLLER_DEF_TYPE_M2 = "m2"
    CONTROLLER_DEF_TYPE_NONE = "none"
    CONTROLLER_DEF_TYPE_NVME = "nvme"
    CONTROLLER_DEF_TYPE_NVME_HHHL = "nvme-hhhl"
    CONTROLLER_DEF_TYPE_NVME_MEZZ = "nvme-mezz"
    CONTROLLER_DEF_TYPE_SLOT_BASED = "slot-based"
    CONTROLLER_SUB_TYPE_NONE = "none"
    CONTROLLER_SUB_TYPE_PSATA = "psata"
    CONTROLLER_SUB_TYPE_SSATA = "ssata"
    DISK_SHARING_SUPPORTED_FALSE = "false"
    DISK_SHARING_SUPPORTED_NO = "no"
    DISK_SHARING_SUPPORTED_TRUE = "true"
    DISK_SHARING_SUPPORTED_YES = "yes"
    FORCE_UPDATE_VERSION_FALSE = "false"
    FORCE_UPDATE_VERSION_NO = "no"
    FORCE_UPDATE_VERSION_TRUE = "true"
    FORCE_UPDATE_VERSION_YES = "yes"
    HOT_PLUG_SUPPORTED_FALSE = "false"
    HOT_PLUG_SUPPORTED_NO = "no"
    HOT_PLUG_SUPPORTED_TRUE = "true"
    HOT_PLUG_SUPPORTED_YES = "yes"
    INT_ID_NONE = "none"
    JBOD_SHARING_SUPPORTED_FALSE = "false"
    JBOD_SHARING_SUPPORTED_NO = "no"
    JBOD_SHARING_SUPPORTED_TRUE = "true"
    JBOD_SHARING_SUPPORTED_YES = "yes"
    ON_BOARD_MEMORY_CHECK_NEEDED_FALSE = "false"
    ON_BOARD_MEMORY_CHECK_NEEDED_NO = "no"
    ON_BOARD_MEMORY_CHECK_NEEDED_TRUE = "true"
    ON_BOARD_MEMORY_CHECK_NEEDED_YES = "yes"
    OOB_CONTROLLER_CLASS_IDENTIFIER_AVILA_ROCK = "avila-rock"
    OOB_CONTROLLER_CLASS_IDENTIFIER_NONE = "none"
    OOB_CONTROLLER_CLASS_IDENTIFIER_NVME = "nvme"
    OOB_INTERFACE_SUPPORTED_FALSE = "false"
    OOB_INTERFACE_SUPPORTED_NO = "no"
    OOB_INTERFACE_SUPPORTED_TRUE = "true"
    OOB_INTERFACE_SUPPORTED_YES = "yes"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    TFM_SUPPORTED_FALSE = "false"
    TFM_SUPPORTED_NO = "no"
    TFM_SUPPORTED_TRUE = "true"
    TFM_SUPPORTED_YES = "yes"
    ZONING_SUPPORTED_FALSE = "false"
    ZONING_SUPPORTED_NO = "no"
    ZONING_SUPPORTED_TRUE = "true"
    ZONING_SUPPORTED_YES = "yes"


class EquipmentLocalDiskControllerDef(ManagedObject):
    """This is EquipmentLocalDiskControllerDef class."""

    consts = EquipmentLocalDiskControllerDefConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentLocalDiskControllerDef", "equipmentLocalDiskControllerDef", "disk-controller", VersionMeta.Version131c, "InputOutput", 0xff, [], [""], ['equipmentLocalDiskControllerCapProvider'], [], ["Get"])

    prop_meta = {
        "auto_config_mode_supported": MoPropertyMeta("auto_config_mode_supported", "autoConfigModeSupported", "string", VersionMeta.Version421a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131c, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_parm_mod_supported": MoPropertyMeta("config_parm_mod_supported", "configParmModSupported", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "controller_def_type": MoPropertyMeta("controller_def_type", "controllerDefType", "string", VersionMeta.Version227b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["dual", "embedded", "m2", "none", "nvme", "nvme-hhhl", "nvme-mezz", "slot-based"], []),
        "controller_sub_type": MoPropertyMeta("controller_sub_type", "controllerSubType", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["none", "psata", "ssata"], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x4, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "disk_sharing_supported": MoPropertyMeta("disk_sharing_supported", "diskSharingSupported", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []),
        "force_update_version": MoPropertyMeta("force_update_version", "forceUpdateVersion", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "hot_plug_supported": MoPropertyMeta("hot_plug_supported", "hotPlugSupported", "string", VersionMeta.Version321d, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version131c, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "jbod_sharing_supported": MoPropertyMeta("jbod_sharing_supported", "jbodSharingSupported", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "on_board_memory_check_needed": MoPropertyMeta("on_board_memory_check_needed", "onBoardMemoryCheckNeeded", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "oob_controller_class_identifier": MoPropertyMeta("oob_controller_class_identifier", "oobControllerClassIdentifier", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["avila-rock", "none", "nvme"], []),
        "oob_interface_supported": MoPropertyMeta("oob_interface_supported", "oobInterfaceSupported", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version211a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["local", "pending-policy", "policy"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131c, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131c, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "tfm_supported": MoPropertyMeta("tfm_supported", "tfmSupported", "string", VersionMeta.Version224b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "zoning_supported": MoPropertyMeta("zoning_supported", "zoningSupported", "string", VersionMeta.Version312b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "autoConfigModeSupported": "auto_config_mode_supported", 
        "childAction": "child_action", 
        "configParmModSupported": "config_parm_mod_supported", 
        "controllerDefType": "controller_def_type", 
        "controllerSubType": "controller_sub_type", 
        "descr": "descr", 
        "diskSharingSupported": "disk_sharing_supported", 
        "dn": "dn", 
        "forceUpdateVersion": "force_update_version", 
        "hotPlugSupported": "hot_plug_supported", 
        "intId": "int_id", 
        "jbodSharingSupported": "jbod_sharing_supported", 
        "name": "name", 
        "onBoardMemoryCheckNeeded": "on_board_memory_check_needed", 
        "oobControllerClassIdentifier": "oob_controller_class_identifier", 
        "oobInterfaceSupported": "oob_interface_supported", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "tfmSupported": "tfm_supported", 
        "zoningSupported": "zoning_supported", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.auto_config_mode_supported = None
        self.child_action = None
        self.config_parm_mod_supported = None
        self.controller_def_type = None
        self.controller_sub_type = None
        self.descr = None
        self.disk_sharing_supported = None
        self.force_update_version = None
        self.hot_plug_supported = None
        self.int_id = None
        self.jbod_sharing_supported = None
        self.name = None
        self.on_board_memory_check_needed = None
        self.oob_controller_class_identifier = None
        self.oob_interface_supported = None
        self.policy_level = None
        self.policy_owner = None
        self.sacl = None
        self.status = None
        self.tfm_supported = None
        self.zoning_supported = None

        ManagedObject.__init__(self, "EquipmentLocalDiskControllerDef", parent_mo_or_dn, **kwargs)



"""This module contains the general information for MgmtSpdmCertificateData ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MgmtSpdmCertificateDataConsts:
    CERT_TYPE_PEM = "pem"


class MgmtSpdmCertificateData(ManagedObject):
    """This is MgmtSpdmCertificateData class."""

    consts = MgmtSpdmCertificateDataConsts()
    naming_props = set(['certId'])

    mo_meta = MoMeta("MgmtSpdmCertificateData", "mgmtSpdmCertificateData", "spdm-cert-[cert_id]", VersionMeta.Version421a, "InputOutput", 0xffffff, [], ["admin"], ['mgmtSpdmCertificateInventory'], [], [None])

    prop_meta = {
        "cert_content": MoPropertyMeta("cert_content", "certContent", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, [], []),
        "cert_id": MoPropertyMeta("cert_id", "certId", "ushort", VersionMeta.Version421a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []),
        "cert_type": MoPropertyMeta("cert_type", "certType", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["pem"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version421a, MoPropertyMeta.INTERNAL, 0x10, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "common_name": MoPropertyMeta("common_name", "commonName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "country_code": MoPropertyMeta("country_code", "countryCode", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version421a, MoPropertyMeta.READ_ONLY, 0x80, 0, 256, None, [], []),
        "is_user_uploaded": MoPropertyMeta("is_user_uploaded", "isUserUploaded", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_common_name": MoPropertyMeta("issuer_common_name", "issuerCommonName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_country_code": MoPropertyMeta("issuer_country_code", "issuerCountryCode", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x400, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_locality": MoPropertyMeta("issuer_locality", "issuerLocality", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x800, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_org_name": MoPropertyMeta("issuer_org_name", "issuerOrgName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x1000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_org_unit_name": MoPropertyMeta("issuer_org_unit_name", "issuerOrgUnitName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x2000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "issuer_state": MoPropertyMeta("issuer_state", "issuerState", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x4000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "locality": MoPropertyMeta("locality", "locality", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x8000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "org_name": MoPropertyMeta("org_name", "orgName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x10000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "org_unit_name": MoPropertyMeta("org_unit_name", "orgUnitName", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x20000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version421a, MoPropertyMeta.READ_ONLY, 0x40000, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version421a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "serial_number": MoPropertyMeta("serial_number", "serialNumber", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x80000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x100000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x200000, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "valid_from": MoPropertyMeta("valid_from", "validFrom", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x400000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
        "valid_to": MoPropertyMeta("valid_to", "validTo", "string", VersionMeta.Version421a, MoPropertyMeta.READ_WRITE, 0x800000, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []),
    }

    prop_map = {
        "certContent": "cert_content", 
        "certId": "cert_id", 
        "certType": "cert_type", 
        "childAction": "child_action", 
        "commonName": "common_name", 
        "countryCode": "country_code", 
        "dn": "dn", 
        "isUserUploaded": "is_user_uploaded", 
        "issuerCommonName": "issuer_common_name", 
        "issuerCountryCode": "issuer_country_code", 
        "issuerLocality": "issuer_locality", 
        "issuerOrgName": "issuer_org_name", 
        "issuerOrgUnitName": "issuer_org_unit_name", 
        "issuerState": "issuer_state", 
        "locality": "locality", 
        "orgName": "org_name", 
        "orgUnitName": "org_unit_name", 
        "rn": "rn", 
        "sacl": "sacl", 
        "serialNumber": "serial_number", 
        "state": "state", 
        "status": "status", 
        "validFrom": "valid_from", 
        "validTo": "valid_to", 
    }

    def __init__(self, parent_mo_or_dn, cert_id, **kwargs):
        self._dirty_mask = 0
        self.cert_id = cert_id
        self.cert_content = None
        self.cert_type = None
        self.child_action = None
        self.common_name = None
        self.country_code = None
        self.is_user_uploaded = None
        self.issuer_common_name = None
        self.issuer_country_code = None
        self.issuer_locality = None
        self.issuer_org_name = None
        self.issuer_org_unit_name = None
        self.issuer_state = None
        self.locality = None
        self.org_name = None
        self.org_unit_name = None
        self.sacl = None
        self.serial_number = None
        self.state = None
        self.status = None
        self.valid_from = None
        self.valid_to = None

        ManagedObject.__init__(self, "MgmtSpdmCertificateData", parent_mo_or_dn, **kwargs)



"""This module contains the general information for PowerRackUnitMember ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class PowerRackUnitMemberConsts:
    OPER_STATE_CAP_INSUFFICIENT = "cap-insufficient"
    OPER_STATE_CAP_OK = "cap-ok"
    OPER_STATE_FW_MISMATCH = "fw-mismatch"
    OPER_STATE_PSU_INSUFFICIENT = "psu-insufficient"
    OPER_STATE_PSU_REDUNDANCY_FAILED = "psu-redundancy-failed"
    OPER_STATE_UNINITIALIZED = "uninitialized"


class PowerRackUnitMember(ManagedObject):
    """This is PowerRackUnitMember class."""

    consts = PowerRackUnitMemberConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("PowerRackUnitMember", "powerRackUnitMember", "ru-member-[id]", VersionMeta.Version141i, "InputOutput", 0x3f, [], ["admin", "power-mgmt", "read-only"], ['powerGroup'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141i, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version141i, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, None, None, None, None, ["cap-insufficient", "cap-ok", "fw-mismatch", "psu-insufficient", "psu-redundancy-failed", "uninitialized"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141i, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141i, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "id": "id", 
        "operState": "oper_state", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.oper_state = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "PowerRackUnitMember", parent_mo_or_dn, **kwargs)



"""This module contains the general information for MemoryPersistentMemoryRegion ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class MemoryPersistentMemoryRegionConsts:
    SOCKET_ID_SOCKET_1 = "socket-1"
    SOCKET_ID_SOCKET_2 = "socket-2"
    SOCKET_ID_SOCKET_3 = "socket-3"
    SOCKET_ID_SOCKET_4 = "socket-4"
    SOCKET_LOCAL_DIMM_NUMBER_10 = "10"
    SOCKET_LOCAL_DIMM_NUMBER_11 = "11"
    SOCKET_LOCAL_DIMM_NUMBER_12 = "12"
    SOCKET_LOCAL_DIMM_NUMBER_14 = "14"
    SOCKET_LOCAL_DIMM_NUMBER_15 = "15"
    SOCKET_LOCAL_DIMM_NUMBER_16 = "16"
    SOCKET_LOCAL_DIMM_NUMBER_2 = "2"
    SOCKET_LOCAL_DIMM_NUMBER_3 = "3"
    SOCKET_LOCAL_DIMM_NUMBER_4 = "4"
    SOCKET_LOCAL_DIMM_NUMBER_6 = "6"
    SOCKET_LOCAL_DIMM_NUMBER_7 = "7"
    SOCKET_LOCAL_DIMM_NUMBER_8 = "8"
    SOCKET_LOCAL_DIMM_NUMBER_NOT_APPLICABLE = "not-applicable"


class MemoryPersistentMemoryRegion(ManagedObject):
    """This is MemoryPersistentMemoryRegion class."""

    consts = MemoryPersistentMemoryRegionConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("MemoryPersistentMemoryRegion", "memoryPersistentMemoryRegion", "region-[id]", VersionMeta.Version404a, "InputOutput", 0x3f, [], ["admin", "pn-equipment", "pn-maintenance", "pn-policy"], ['memoryPersistentMemoryConfiguration'], ['memoryPersistentMemoryNamespace'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version404a, MoPropertyMeta.INTERNAL, 0x2, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "dimm_locater_ids": MoPropertyMeta("dimm_locater_ids", "dimmLocaterIds", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []),
        "free_capacity": MoPropertyMeta("free_capacity", "freeCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
        "health_state": MoPropertyMeta("health_state", "healthState", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version404a, MoPropertyMeta.NAMING, 0x8, None, None, None, [], []),
        "interleaved_set_id": MoPropertyMeta("interleaved_set_id", "interleavedSetId", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "persistent_memory_type": MoPropertyMeta("persistent_memory_type", "persistentMemoryType", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "socket_id": MoPropertyMeta("socket_id", "socketId", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["socket-1", "socket-2", "socket-3", "socket-4"], []),
        "socket_local_dimm_number": MoPropertyMeta("socket_local_dimm_number", "socketLocalDimmNumber", "string", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["10", "11", "12", "14", "15", "16", "2", "3", "4", "6", "7", "8", "not-applicable"], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version404a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "total_capacity": MoPropertyMeta("total_capacity", "totalCapacity", "long", VersionMeta.Version404a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^([\-]?)([0-9]{1,15})$""", [], []),
    }

    prop_map = {
        "childAction": "child_action", 
        "dimmLocaterIds": "dimm_locater_ids", 
        "dn": "dn", 
        "freeCapacity": "free_capacity", 
        "healthState": "health_state", 
        "id": "id", 
        "interleavedSetId": "interleaved_set_id", 
        "persistentMemoryType": "persistent_memory_type", 
        "rn": "rn", 
        "sacl": "sacl", 
        "socketId": "socket_id", 
        "socketLocalDimmNumber": "socket_local_dimm_number", 
        "status": "status", 
        "totalCapacity": "total_capacity", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.dimm_locater_ids = None
        self.free_capacity = None
        self.health_state = None
        self.interleaved_set_id = None
        self.persistent_memory_type = None
        self.sacl = None
        self.socket_id = None
        self.socket_local_dimm_number = None
        self.status = None
        self.total_capacity = None

        ManagedObject.__init__(self, "MemoryPersistentMemoryRegion", parent_mo_or_dn, **kwargs)



"""This module contains the general information for ExtvmmFabricNetworkDefinition ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class ExtvmmFabricNetworkDefinitionConsts:
    ALLOWED_VNIC_TYPE_ETHER = "ether"
    ALLOWED_VNIC_TYPE_FC = "fc"
    ALLOWED_VNIC_TYPE_IPC = "ipc"
    ALLOWED_VNIC_TYPE_SCSI = "scsi"
    ALLOWED_VNIC_TYPE_UNKNOWN = "unknown"
    INT_ID_NONE = "none"
    POLICY_OWNER_LOCAL = "local"
    POLICY_OWNER_PENDING_POLICY = "pending-policy"
    POLICY_OWNER_POLICY = "policy"
    REF_OPER_STATE_INVALID_REFERENCE = "invalid-reference"
    REF_OPER_STATE_UP = "up"


class ExtvmmFabricNetworkDefinition(ManagedObject):
    """This is ExtvmmFabricNetworkDefinition class."""

    consts = ExtvmmFabricNetworkDefinitionConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("ExtvmmFabricNetworkDefinition", "extvmmFabricNetworkDefinition", "fabric-network-def-[name]", VersionMeta.Version221b, "InputOutput", 0x3ff, [], ["admin", "ls-network", "ls-network-policy"], ['extvmmFabricNetwork'], ['extvmmVMNetworkDefinition'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "allowed_vnic_type": MoPropertyMeta("allowed_vnic_type", "allowedVnicType", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["ether", "fc", "ipc", "scsi", "unknown"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""(([0-9a-fA-F]){8}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){4}\-([0-9a-fA-F]){12})|0""", [], []),
        "int_id": MoPropertyMeta("int_id", "intId", "string", VersionMeta.Version221b, MoPropertyMeta.INTERNAL, None, None, None, None, ["none"], ["0-4294967295"]),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version221b, MoPropertyMeta.NAMING, 0x40, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []),
        "policy_level": MoPropertyMeta("policy_level", "policyLevel", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []),
        "policy_owner": MoPropertyMeta("policy_owner", "policyOwner", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["local", "pending-policy", "policy"], []),
        "primary_vlan_id": MoPropertyMeta("primary_vlan_id", "primaryVlanId", "uint", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], ["1-4093"]),
        "ref_oper_state": MoPropertyMeta("ref_oper_state", "refOperState", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["invalid-reference", "up"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version221b, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version221b, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
    }

    prop_map = {
        "allowedVnicType": "allowed_vnic_type", 
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "guid": "guid", 
        "intId": "int_id", 
        "name": "name", 
        "policyLevel": "policy_level", 
        "policyOwner": "policy_owner", 
        "primaryVlanId": "primary_vlan_id", 
        "refOperState": "ref_oper_state", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.allowed_vnic_type = None
        self.child_action = None
        self.descr = None
        self.guid = None
        self.int_id = None
        self.policy_level = None
        self.policy_owner = None
        self.primary_vlan_id = None
        self.ref_oper_state = None
        self.sacl = None
        self.status = None

        ManagedObject.__init__(self, "ExtvmmFabricNetworkDefinition", parent_mo_or_dn, **kwargs)



"""This module contains the general information for CommSnmpUser ManagedObject."""

from ...ucsmo import ManagedObject
from ...ucscoremeta import MoPropertyMeta, MoMeta
from ...ucsmeta import VersionMeta


class CommSnmpUserConsts:
    AUTH_MD5 = "md5"
    AUTH_SHA = "sha"
    CONFIG_STATE_NOT_APPLIED = "not-applied"
    CONFIG_STATE_OK = "ok"
    PRIV_PWD_SET_FALSE = "false"
    PRIV_PWD_SET_NO = "no"
    PRIV_PWD_SET_TRUE = "true"
    PRIV_PWD_SET_YES = "yes"
    PWD_SET_FALSE = "false"
    PWD_SET_NO = "no"
    PWD_SET_TRUE = "true"
    PWD_SET_YES = "yes"
    USE_AES_FALSE = "false"
    USE_AES_NO = "no"
    USE_AES_TRUE = "true"
    USE_AES_YES = "yes"


class CommSnmpUser(ManagedObject):
    """This is CommSnmpUser class."""

    consts = CommSnmpUserConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("CommSnmpUser", "commSnmpUser", "snmpv3-user-[name]", VersionMeta.Version101e, "InputOutput", 0x7ff, [], ["aaa", "admin"], ['commSnmp'], ['aaaCimcSession', 'faultInst'], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "auth": MoPropertyMeta("auth", "auth", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["md5", "sha"], []),
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101e, MoPropertyMeta.INTERNAL, 0x4, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []),
        "config_state": MoPropertyMeta("config_state", "configState", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applied", "ok"], []),
        "config_status_message": MoPropertyMeta("config_status_message", "configStatusMessage", "string", VersionMeta.Version211a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []),
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []),
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []),
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101e, MoPropertyMeta.NAMING, 0x20, None, None, r"""[a-zA-Z][a-zA-Z0-9_.@-]{0,31}""", [], []),
        "priv_pwd_set": MoPropertyMeta("priv_pwd_set", "privPwdSet", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "privpwd": MoPropertyMeta("privpwd", "privpwd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x40, None, None, r"""[!""#%&'\(\)\*\+,\-\./:;<>@\[\\\]\^_`\{\|\}~a-zA-Z0-9]{0,127}""", [], []),
        "pwd": MoPropertyMeta("pwd", "pwd", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""[!""#%&'\(\)\*\+,\-\./:;<>@\[\\\]\^_`\{\|\}~a-zA-Z0-9]{0,127}""", [], []),
        "pwd_set": MoPropertyMeta("pwd_set", "pwdSet", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []),
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101e, MoPropertyMeta.READ_ONLY, 0x100, 0, 256, None, [], []),
        "sacl": MoPropertyMeta("sacl", "sacl", "string", VersionMeta.Version302c, MoPropertyMeta.READ_ONLY, None, None, None, r"""((none|del|mod|addchild|cascade),){0,4}(none|del|mod|addchild|cascade){0,1}""", [], []),
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x200, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []),
        "use_aes": MoPropertyMeta("use_aes", "useAes", "string", VersionMeta.Version101e, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["false", "no", "true", "yes"], []),
    }

    prop_map = {
        "auth": "auth", 
        "childAction": "child_action", 
        "configState": "config_state", 
        "configStatusMessage": "config_status_message", 
        "descr": "descr", 
        "dn": "dn", 
        "name": "name", 
        "privPwdSet": "priv_pwd_set", 
        "privpwd": "privpwd", 
        "pwd": "pwd", 
        "pwdSet": "pwd_set", 
        "rn": "rn", 
        "sacl": "sacl", 
        "status": "status", 
        "useAes": "use_aes", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.auth = None
        self.child_action = None
        self.config_state = None
        self.config_status_message = None
        self.descr = None
        self.priv_pwd_set = None
        self.privpwd = None
        self.pwd = None
        self.pwd_set = None
        self.sacl = None
        self.status = None
        self.use_aes = None

        ManagedObject.__init__(self, "CommSnmpUser", parent_mo_or_dn, **kwargs)
